@@ -150,6 +150,8 @@ static void
 wnck_screen_class_init (WnckScreenClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+  _wnck_init ();
   
   parent_class = g_type_class_peek_parent (klass);
   
@@ -243,7 +245,7 @@ wnck_screen_finalize (GObject *object)
   WnckScreen *screen;
 
   screen = WNCK_SCREEN (object);
-
+  
   unqueue_update (screen);
 
   /* FIXME this isn't right, we need to destroy the items
@@ -253,6 +255,8 @@ wnck_screen_finalize (GObject *object)
   g_list_free (screen->priv->mapped_windows);
   g_list_free (screen->priv->stacked_windows);
   g_list_free (screen->priv->workspaces);
+
+  screens[screen->priv->number] = NULL;
   
   g_free (screen->priv);
   
@@ -335,7 +339,7 @@ wnck_screen_get_for_root (gulong root_window_id)
   i = 0;
   while (i < ScreenCount (gdk_display))
     {
-      if (screens[i]->priv->xroot == root_window_id)
+      if (screens[i] != NULL && screens[i]->priv->xroot == root_window_id)
         return screens[i];
       
       ++i;
